<?php defined( 'ABSPATH' ) or die( 'No script kiddies please!' );
/*
Plugin Name: OSI Affiliate WooCommerce
Plugin URI: https://www.osiaffiliate.com/wooCommerce
Description: OSI Affiliate Software for WooCommerce integration plugin.
Version: 1.0
Author: OSI Affiliate Software
Author URI: https://www.osiaffiliate.com
License: GPL2
*/

class OSI_Affiliate_WooCommerce {
	public function __construct() {
		add_action('admin_menu',array($this,'create_plugin_settings_page'));
		add_action('admin_init',array($this,'setup_sections'));
		add_action('admin_init',array($this,'setup_fields'));
		$osi_subdomain = get_option('osi_subdomain');

		if (!empty($osi_subdomain)) {
			add_action('woocommerce_thankyou',array($this,'osi_thankyou_code'));
		}
	} // public function __construct()

	public function osi_thankyou_code($order_id) {
		if (empty($order_id)) {
			exit;
		}

		$order = wc_get_order($order_id);
		if (empty($order)) {
			exit;
		}

		$osi_subdomain = get_option('osi_subdomain');
		$order_total = $order->get_total();

		$coupons = $order->get_items('coupon');
		$PromoCode = '';
		if (!empty($coupons)) {
			foreach ($coupons as $coupon) {
				$PromoCode = $coupon['name'];
				break;
			}
		}

		if (!empty($osi_subdomain)
		    and !empty($order_total)
		) {
			echo '<script>
				function hideIF() {	
					document.getElementById("IF").style.visibility = "";
				}
				function getSaleInfo() {
					document.getElementById("st_code").style.visibility = "hidden";
					document.getElementById("st_code").innerHTML=\'<iframe src="https://'.$osi_subdomain.'.ositracker.com/sales/salejs/amount:'.$order_total.'/transaction:'.$order_id.'/PromoCode:'.$PromoCode.'" alt="" id=IF width=50 height=50 border="0" frameborder="0" onload="hideIF()">\';
				}			
				window.onload = getSaleInfo;
				</script>
				<div id="st_code"></div>
			';
		}
	} // public function osi_thankyou_code($order_id)

	public function create_plugin_settings_page() {
		$page_title = 'OSI Affiliate';
		$menu_title = 'OSI Affiliate';
		$capability = 'manage_options';
		$slug = 'osi_wc_fields';
		$callback = array($this,'plugin_settings_page_content');
		$icon = 'dashicons-networking';
		$position = 100;

		add_menu_page($page_title,$menu_title,$capability,$slug,$callback,$icon,$position);
	} // public function create_plugin_settings_page()

	public function plugin_settings_page_content() {
		?>
		<div class="wrap">
			<h2>OSI Affiliate Settings Page</h2>
			<?php
			if (isset($_GET['settings-updated']) && $_GET['settings-updated']) {
				  $this->admin_notice();
			}
			?>
			<form method="POST" action="options.php">
				<?php
				settings_fields('osi_wc_fields');
				do_settings_sections('osi_wc_fields');
				submit_button();
				?>
			</form>
		</div>
		<?php
	} // public function plugin_settings_page_content()
	
	public function admin_notice() {
		?>
		<div class="notice notice-success is-dismissible">
			<p>Your settings have been updated!</p>
		</div>
		<?php
	} // public function admin_notice()

	public function setup_sections() {
		add_settings_section('our_first_section','WooCommerce',array($this,'section_callback'),'osi_wc_fields');
	} // public function setup_sections()

	public function section_callback($arguments) {
		switch ($arguments['id']) {
			case 'our_first_section':
				echo 'Update these settings to enable automatic sales tracking.';
			break;
		}
	} // public function section_callback( $arguments )

	public function setup_fields() {
		$fields = array(
			array(
				'uid' => 'osi_subdomain',
				'label' => 'OSI Affiliate Software Subdomain',
				'section' => 'our_first_section',
				'type' => 'text',
				'placeholder' => 'Your OSI Affiliate Software Subdomain',
				'helper' => 'i.e company1 in company1.ositracker.com',
				'supplimental' => 'Put here only the subdomain part, not the full URL',
			),
		);
		foreach ($fields as $field) {
			add_settings_field($field['uid'],$field['label'],array($this,'field_callback'),'osi_wc_fields',$field['section'],$field);
			register_setting('osi_wc_fields',$field['uid']);
		}
	} // public function setup_fields()

	public function field_callback($arguments) {
		$value = get_option($arguments['uid']);

		if (!$value) {
			$value = $arguments['default'];
		}

		switch ($arguments['type']) {
			case 'text':
				printf('<input name="%1$s" id="%1$s" type="%2$s" placeholder="%3$s" value="%4$s" />',$arguments['uid'],$arguments['type'],$arguments['placeholder'],$value);
			break;
		}

		if ($helper = $arguments['helper']) {
			printf('<span class="helper"> %s</span>',$helper);
		}

		if ($supplimental = $arguments['supplimental']) {
			printf('<p class="description">%s</p>',$supplimental);
		}
	} // public function field_callback( $arguments )
} // class OSI_Affiliate_WooCommerce

new OSI_Affiliate_WooCommerce();
